@@ -131,6 +131,8 @@ class GenericAPI:
                         f"status code: {r.status_code}\n"
                         f"content: {r.content.decode()}"
                     )
+                else:
+                    return r
             except (requests.ConnectionError, APIError) as e:
                 attempts -= 1
 
