@@ -1,5 +1,4 @@
 import collections
-from copy import deepcopy
 from enum import Enum
 from functools import partial
 import math
@@ -36,7 +35,8 @@ class FileTransferProgressHandler:
         if not callable(callback):
             raise ValueError("callback must be callable")
 
-        # TODO:  Callback must accept an integer (number of chunks already added).
+        # TODO:  Callback must accept an integer
+        #        (number of chunks already added).
 
         self.chunk_size = chunk_size
         self.total_size = total_size
@@ -65,7 +65,7 @@ class FileTransferProgressHandler:
 
         if self.current_size >= self.total_size:
             # NOTE:  Do not use self.current_size as the numerator.
-            #        It may be larger than self.total_size, for reasons unknown.
+            #        It may be larger than self.total_size, for reasons
             self.callback(math.ceil(self.total_size / self.chunk_size))
             return
 
@@ -130,10 +130,7 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.get,
             url=url,
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            params={'id': id,},
-            verify=self.auth.verify,
+            params={'id': id},
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -142,7 +139,8 @@ class FilesAPI(GenericAPI):
         else:
             self._report_api_error(response=r)
 
-    def get_from_location(self, space_id, path=None, file_type=None):
+    def get_from_location(self, space_id, path=None, file_type=None,
+                          start=0, length=25):
         """
         Get HyperThought files/folders from a specific location.
 
@@ -158,6 +156,10 @@ class FilesAPI(GenericAPI):
         file_type : FileType or None
             An enum value for the type of files to get.  A None value will
             default to FileType.FILES_AND_FOLDERS.
+        start : int
+            Start index for results pagination (0-based).
+        length : int
+            Pagination page length.
 
         Returns
         -------
@@ -170,9 +172,12 @@ class FilesAPI(GenericAPI):
         file_type = self._validate_file_type(file_type)
 
         url = f"{self._files_base_url}workspace/{space_id}/"
-        headers = self._auth.get_headers()
-        cookies = self._auth.get_cookies()
-        params = {'path': path}
+        params = {
+            'path': path,
+            # Convert to 1-based indexing used by database method.
+            'start': start + 1,
+            'pageLength': length,
+        }
 
         if file_type is None:
             params['type'] = self.FileType.FILES_AND_FOLDERS.value
@@ -182,10 +187,7 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.get,
             url,
-            headers=headers,
-            cookies=cookies,
             params=params,
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -230,8 +232,6 @@ class FilesAPI(GenericAPI):
         path = self._validate_path(path)
 
         url = f"{self._files_base_url}workspace/{space_id}/"
-        headers = self._auth.get_headers()
-        cookies = self._auth.get_cookies()
         params = {
             'path': path,
             'start': 1,
@@ -242,10 +242,7 @@ class FilesAPI(GenericAPI):
             curried_request = partial(
                 requests.get,
                 url=url,
-                headers=headers,
-                cookies=cookies,
                 params=params,
-                verify=self.auth.verify,
             )
             r = self.attempt_api_call(curried_request=curried_request)
 
@@ -379,7 +376,7 @@ class FilesAPI(GenericAPI):
         -------
         An object link string.
         """
-        if not id_ is None and not isinstance(id_, str):
+        if id_ is not None and not isinstance(id_, str):
             raise ValueError(f"string expected for id_, found {type(path)}")
 
         if id_ is None:
@@ -440,15 +437,12 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.post,
             url=url,
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
             json={
                 'space_id': space_id,
                 'path': path,
                 'name': name,
                 'metadata': metadata,
             },
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -517,8 +511,6 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.post,
             url=url,
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
             json={
                 'sourceSpaceId': source_space_id,
                 'sourceParentFolderId': source_parent_folder_id,
@@ -526,7 +518,6 @@ class FilesAPI(GenericAPI):
                 'destinationParentFolderId': destination_parent_folder_id,
                 'fileIds': file_ids,
             },
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -676,10 +667,7 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.delete,
             url='{}/api/files/'.format(self._base_url),
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            json={'ids': ids,},
-            verify=self.auth.verify,
+            json={'ids': ids},
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -709,15 +697,12 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.patch,
             url=f"{self._base_url}/api/files/",
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
             json={
                 'file_id': file_id,
                 'updates': {
                     'metadata': new_metadata,
                 }
             },
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -739,9 +724,6 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.get,
             url=f'{self._base_url}/api/files/backend/',
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -807,8 +789,6 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.post,
             url=f"{self._files_base_url}generate-upload-url/",
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
             json={
                 'workspaceId': space_id,
                 'path': path,
@@ -816,7 +796,6 @@ class FilesAPI(GenericAPI):
                 'size': size,
                 'metadata': metadata,
             },
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -928,9 +907,6 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.patch,
             url=f"{self._files_base_url}{file_id}/temp-to-perm/",
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -959,12 +935,9 @@ class FilesAPI(GenericAPI):
         curried_request = partial(
             requests.get,
             url=f"{self._base_url}/api/files/generate-download-url/",
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
             params={
                 'id': file_id,
             },
-            verify=self.auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
@@ -1026,16 +999,19 @@ class FilesAPI(GenericAPI):
                             progress_handler.add(DOWNLOAD_CHUNK_SIZE)
 
     def _validate_id(self, id_):
-        assert isinstance(id_, str), f"expected string as id, found {type(id_)}"
+        assert isinstance(id_, str), (
+            f"expected string as id, found {type(id_)}")
         return id_
 
     def _validate_space(self, space=None):
         if space is None:
             space = 'user'
 
-        # TODO:  Call error-handling function instead of raising an AssertionError.
+        # TODO:  Call error-handling function instead of raising an
+        #        AssertionError.
         #        Same goes for all assertions in validation methods.
-        assert space in ('group', 'project', 'user',), f"Invalid space: {space}"
+        assert space in ('group', 'project', 'user',), (
+            f"Invalid space: {space}")
 
         return space
 
