@@ -12,6 +12,10 @@ from ...metadata import MetadataItem
 from ._construction import algorithms as alg, xml_generation as xmlgen
 
 
+class NotFoundError(Exception):
+    pass
+
+
 class Element:
     """
     Base class for a workflow element.
@@ -54,7 +58,12 @@ class Element:
         self._notes = notes
         self._due_date = due_date
         self._parent = parent
-        self._parent_id = parent_id
+
+        if parent:
+            self._parent_id = parent.id
+        else:
+            self._parent_id = parent_id
+
         self._successors = {}
         self._predecessors = {}
 
@@ -646,7 +655,101 @@ class WorkflowAPI(GenericAPI):
             # NOTE:  This method will throw an exception.
             self._report_api_error(response=r)
 
-    def create_workflow(self, workflow, update_parent=False,
+    def _get_permissions(self, element, space_id=None):
+        """Get permissions for a workflow element."""
+        if not isinstance(element, Element):
+            raise ValueError("element must be an instance of Element")
+
+        if space_id:
+            return {
+                'workspaces': {
+                    space_id: 'edit'
+                }
+            }
+        elif element.parent_id:
+            parent = self.get_document(document_id=element.parent_id)
+
+            if not parent:
+                raise NotFoundError(
+                    f"The parent workflow id, '{element.parent_id}', does "
+                    "not correspond to a valid workflow document"
+                )
+
+            return parent['permissions']
+        else:
+            raise ValueError(
+                f"Element with id {element.id} must have a parent_id "
+                "if no space_id argument is provided"
+            )
+
+    def redraw_canvas(self, workflow_id):
+        """
+        Redraw a workflow canvas.
+
+        This will place elements automatically according to the algorithm
+        used in workflow generation.
+
+        Parameters
+        ----------
+        workflow_id : str
+            The id of the workflow to be redrawn.
+        """
+        # Get parent workflow.
+        workflow = self.get_document(document_id=workflow_id)
+
+        # Update XML.
+        children = []
+
+        for child_id in workflow['children']:
+            child_document = self.get_document(document_id=child_id)
+            # Translate into form needed for XML construction.
+            child = {
+                'id': child_id,
+                'client_id': child_document['clientId'],
+                'type': child_document['processType'],
+                'name': child_document['name'],
+                'predecessors': child_document['predecessors'],
+                'successors': child_document['successors'],
+            }
+            children.append(child)
+
+        children = alg.coordinates.add_coordinates(children)
+        xml_ = tostring(xmlgen.create_xml(logical_children=children)).decode()
+        xml_ = xml_.replace("\"", "\'")
+        workflow['xml'] = xml_
+
+        # Commit changes.
+        self.update_document(updated_document=workflow)
+
+    def _update_parent_workflow(self, parent_id, new_child_id):
+        """
+        Update a parent workflow when a client adds new elements to it.
+
+        This should only be called when new elements are added to existing
+        workflows.
+
+        Parameters
+        ----------
+        parent_id : str
+            The id of the parent workflow to be updated.
+        new_child_id : str
+            The id of the child element to be added.
+        """
+        # Get parent workflow.
+        parent = self.get_document(document_id=parent_id)
+
+        # Add new child id to children.
+        child_ids = set(parent['children'])
+        child_ids.add(new_child_id)
+        parent['children'] = list(child_ids)
+
+        # Commit changes.
+        self.update_document(updated_document=parent)
+
+        # Update XML.
+        self.redraw_canvas(workflow_id=parent_id)
+
+    def create_workflow(self, workflow, update_parent=True,
                         check_validity=True, permissions=None):
         """
         Create a workflow document (as opposed to process or decision).
@@ -669,23 +772,11 @@ class WorkflowAPI(GenericAPI):
         if check_validity and not workflow.is_valid():
             raise ValueError(f"invalid workflow: {workflow}")
 
-        # TODO:  Get space_id from parent_id if parent is None but parent_id is
-        #        not.  (That is, a workflow is being added as a child to an
-        #        existing workflow.)
-        if not permissions and not workflow.space_id:
-            raise ValueError(f"workflow {workflow} has no space_id")
-
-        # Get permissions as needed.
         if not permissions:
-            permissions = {
-                'workspaces': {
-                    workflow.space_id: 'edit'
-                }
-            }
-
-        # TODO:  implement parent updates.
-        if update_parent:
-            raise NotImplementedError("parent updates not yet implemented")
+            permissions = self._get_permissions(
+                element=workflow,
+                space_id=workflow.space_id,
+            )
 
         # Create XML for canvas.
         children = [child.to_json() for child in workflow.children]
@@ -741,6 +832,12 @@ class WorkflowAPI(GenericAPI):
             # NOTE:  This method will throw an exception.
             self._report_api_error(response=r)
 
+        if update_parent and workflow.parent_id:
+            self._update_parent_workflow(
+                new_child_id=workflow.id,
+                parent_id=workflow.parent_id,
+            )
+
         for child in workflow.children:
             if isinstance(child, Process):
                 self.create_process(
@@ -760,7 +857,7 @@ class WorkflowAPI(GenericAPI):
                 # TODO:  Raise exception.
                 raise Exception(f"unimplemented child type: {child.type}")
 
-    def create_process(self, process, update_parent=False, check_validity=True,
+    def create_process(self, process, update_parent=True, check_validity=True,
                        permissions=None):
         """
         Create a process document (as opposed to workflow or decision).
@@ -783,13 +880,11 @@ class WorkflowAPI(GenericAPI):
         if check_validity and not process.is_valid():
             raise ValueError(f"invalid process: {process}")
 
-        # TODO:  Get permissions from process parent.
         if not permissions:
-            raise ValueError(f"permissions needed for process {process}")
+            permissions = self._get_permissions(element=process)
 
-        # TODO:  implement parent updates.
-        if update_parent:
-            raise NotImplementedError("parent updates not yet implemented")
+        if not process.parent_id:
+            raise ValueError(f"Process without parent_id: {process.id}")
 
         username = self._auth.get_username()
         create_date = datetime.now().isoformat()
@@ -825,6 +920,12 @@ class WorkflowAPI(GenericAPI):
             # NOTE:  This method will throw an exception.
             self._report_api_error(response=r)
 
+        if update_parent:
+            self._update_parent_workflow(
+                new_child_id=process.id,
+                parent_id=process.parent_id,
+            )
+
         # Separate call needed for metadata.
         # TODO:  Modify POST endpoint to accept metadata.
         if process.metadata:
@@ -836,3 +937,30 @@ class WorkflowAPI(GenericAPI):
             document = self.get_document(document_id=process.id)
             document['metadata'] = process.get_api_formatted_metadata()
             self.update_document(document)
+
+    def add_link(self, source_id, target_id):
+        """
+        Add a predecessor-successor relationship between workflow elements.
+
+        Parameters
+        ----------
+        source_id : str
+            The id of the element at the head of the edge connecting the two
+            elements.
+        target_id : str
+            The id of the element at the tail of the edge.
+        """
+        curried_request = partial(
+            requests.post,
+            url=(
+                f"{self._workflow_base_url}"
+                f"process/{source_id}/link/{target_id}/"
+            ),
+        )
+        r = self.attempt_api_call(curried_request=curried_request)
+
+        if r.status_code >= ERROR_THRESHOLD:
+            # NOTE:  This method will throw an exception.
+            self._report_api_error(response=r)
+
+        return r.json()
