@@ -20,7 +20,8 @@ def find_root(elements):
     ----------
     elements : list of dict
         Keys include 'id', 'name', 'type', 'predecessors', 'successors',
-        'children' for ('workflow' types), and 'metadata' (for 'process' types).
+        'children' for ('workflow' types), and 'metadata'
+        (for 'process' types).
 
     Returns
     -------
@@ -28,7 +29,7 @@ def find_root(elements):
     """
     all_ids = {element[ID_KEY] for element in elements}
     child_ids = []
-    
+
     for element in elements:
         if CHILDREN_KEY in element:
             child_ids.extend(element[CHILDREN_KEY])
